Crate serde_xpath

Crate serde_xpath 

Re-exports

pub use de::__private;
pub use error::Error;

Modules

de
error
xpath

Structs

Text
Marker type for extracting text content from an element

Traits

FromXml
Trait for types that can be deserialized from XML using XPath

Functions

from_str
Deserialize a type from an XML string
from_str_with_descriptor
Deserialize a type from an XML string using the XPath-based deserializer This is called by the generated Deserialize implementations

Derive Macros

Deserialize