Re-exports
Modules
Structs
- Text
- Marker type for extracting text content from an element
Traits
- FromXml
- Trait for types that can be deserialized from XML using XPath
Functions
- from_
str - Deserialize a type from an XML string
- from_
str_ with_ descriptor - Deserialize a type from an XML string using the XPath-based deserializer This is called by the generated Deserialize implementations